@@ -22,14 +22,12 @@
 
 #include <testsuite_hooks.h>
 
-// libstdc++/7986
+// c++/3111
 int main()
 {
   using namespace __gnu_test;
 
-  // Equivalent, but formatting difference in void argument.
-  //  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(void), int (*)(void))");
-  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(), int (*)())");
+  verify_demangle("_Z1fKPFiiE", "f(int (* const)(int))");
 
   return 0;
 }
